//---------------------------------------------------------------------------
#ifndef QueryDialogH
#define QueryDialogH
//---------------------------------------------------------------------------
#include <SysUtils.hpp>
#include <Controls.hpp>
#include <Classes.hpp>
#include <Forms.hpp>
#include <DBGrids.hpp>
#include <Grids.hpp>
#include "NewClasses.h"
#include "QueryDlg.h"
#include "QDateEdit.h"
//---------------------------------------------------------------------------
//-- type declarations -------------------------------------------------------
enum TQueryType { qtFilter, qtSQL };
enum TFieldOrder { orCreate, orTag };
enum TOpType { opSymbol, opText };
enum TRelation { rlAnd, rlOr };

class PACKAGE TQueryDialog : public TComponent
{
private:
	String FDialogTitle;
    TQueryType FQueryType;
    TRelation FRelation;
    Integer FDialogWidth;
    Integer FDialogHeight;
    Integer FDialogTop;
    Integer FDialogLeft;
    Integer FHelpContext;
    TFieldOrder FFieldOrder;
    String FHelpFile;
    String FDateTimeFormat;
    String FDateFormat;
    String FCalDateFormat;
    String FCalDateTimeFormat;
    AnsiString FQueryString;
    Boolean FClearDialog;
    Boolean FShowFieldHints;
    Boolean FAutoSize;
    Boolean FHighlightPrompts;
    TOpType FOpType;
    TColor FHighlightColor;
    TFormStyle FFormStyle;
    TFormBorderStyle FBorderStyle;
    TPosition FPosition;
    TPrintScale FPrintScale;
    TFont *FDialogFont;
    TSQLOptions *FSQLOptions;
    TControlScrollBars* FHorzScrollBar;
    TControlScrollBars* FVertScrollBar;
    TNotifyEvent FOnMDIResultOK;
    TBorderIcons FBorderIcons;
    //implementation
    TLabel* __fastcall AddFieldPrompt(AnsiString Caption, int Top);
    TOpComboBox* __fastcall AddOperators(TFieldType DataType, int Top, int Left, bool ExtendedSQL);
	TQEdit* __fastcall AddEditBox(TFieldType DataType, AnsiString FieldName, AnsiString FldHint, TEditCharCase CharCase, int Top, int Left);
	TQListBox* __fastcall AddListBox(TFieldType DataType, AnsiString FieldName, AnsiString FldHint, TDBListBox *DBListBox, int Top, int Left);
	TQComboBox* __fastcall AddComboBox(TFieldType DataType, AnsiString FieldName, AnsiString FldHint, TDBComboBox *DBComboBox, int Top, int Left);
    TQComboBox* __fastcall AddComboBox(TFieldType DataType, AnsiString FieldName, AnsiString FldHint, TStrings *Values, int Top, int Left);
	TQCheckBox* __fastcall AddCheckBox(TFieldType DataType, AnsiString FieldName, AnsiString FldHint, TDBCheckBox *DBCheckBox, int Top, int Left);
	TQRadioGroup* __fastcall AddRadioGroup(AnsiString Caption, TFieldType DataType, AnsiString FieldName, AnsiString FldHint, TDBRadioGroup *DBRadioGroup, int Top, int Left);
	TQDBLookupListBox* __fastcall AddLookupListBox(TFieldType DataType, AnsiString FieldName, AnsiString FldHint, TDBLookupListBox *DBLookupListBox, int Top, int Left);
	TQDBLookupComboBox* __fastcall AddLookupComboBox(TFieldType DataType, AnsiString FieldName, AnsiString FldHint, TDBLookupComboBox *DBLookupComboBox, int Top, int Left);
    TQDateEdit* __fastcall AddDateBox(TFieldType DataType, AnsiString FieldName, AnsiString FldHint, int Top, int Left, AnsiString DisplayFormat);
    TOpComboBox* __fastcall GetComboBox(TObject *ComponentPtr);
    TLabel* __fastcall GetQueryLabel(TWinControl *ComponentPtr);
    void __fastcall SetDialogFont(TFont *Font);
    int __fastcall SetupQueryForm(TForm *FormToQuery);
    int __fastcall SetupQueryForm(TDBGrid *GridToQuery);
    int __fastcall SetupQueryForm(TDataSet *DataSetToQuery);
    bool __fastcall FieldTypeSupported(TFieldType DataType);
    void __fastcall AutoSizeForm(int LastFieldPos);
    void __fastcall SearchValueExit(TObject *Sender);
    void __fastcall SearchValueEnter(TObject *Sender);
    void __fastcall OpComboBoxExit(TObject *Sender);
    void __fastcall OpComboBoxEnter(TObject *Sender);
    void __fastcall ComboBoxChange(TObject *Sender);
    bool __fastcall ValidateSearchValue(AnsiString Text, int DataType, AnsiString Operator);
    void __fastcall ClearFormClick(TObject *Sender);
    void __fastcall MakeQueryStr(AnsiString& QueryString);
    AnsiString __fastcall GetDefaultHint(TFieldType DataType, AnsiString Caption, AnsiString ObjectName);
    void __fastcall OnFormResize(TObject *Sender);
    void __fastcall OnMDIClose(TObject *Sender, TCloseAction &Action);
    void __fastcall SetFormValues(TQueryForm *NewForm);
	void __fastcall SetFormStyle(TQueryForm *NewForm);
    void __fastcall SetBorderIcons(TBorderIcons Value);
    void __fastcall ShowAboutForm(void);
    int OpBoxWidth;
    int MinFldSize;
    int OpLeft;
    int ValLeft;
protected:
public:
	__fastcall TQueryDialog(TComponent* Owner);
    __fastcall ~TQueryDialog();
    bool __fastcall Execute(TForm *FormToQuery);
    bool __fastcall Execute(TDBGrid *GridToQuery);
    bool __fastcall Execute(TDataSet *DataSetToQuery);
    void __fastcall ResetForm(void);
__published:
    __property String DialogTitle = {read=FDialogTitle, write=FDialogTitle};
    __property TQueryType QueryType = {read=FQueryType, write=FQueryType, default=0};
    __property Integer DialogWidth = {read=FDialogWidth, write=FDialogWidth, default=450};
    __property Integer DialogHeight = {read=FDialogHeight, write=FDialogHeight, default=450};
    __property Integer DialogTop = {read=FDialogTop, write=FDialogTop, default=200};
    __property Integer DialogLeft = {read=FDialogLeft, write=FDialogLeft, default=300};
    __property TFont *DialogFont = {read=FDialogFont, write=SetDialogFont, stored=true};
	__property String DateFormat = {read=FDateFormat, write=FDateFormat};
    __property String DateTimeFormat = {read=FDateTimeFormat, write=FDateTimeFormat};
    __property String CalDateFormat = {read=FCalDateFormat, write=FCalDateFormat};
    __property String CalDateTimeFormat = {read=FCalDateTimeFormat, write=FCalDateTimeFormat};
    __property Boolean ClearDialog = {read=FClearDialog, write=FClearDialog};
    __property TSQLOptions *SQLOptions = {read=FSQLOptions, write=FSQLOptions};
    __property TFormStyle FormStyle = {read=FFormStyle, write=FFormStyle, stored=true, default=0};
    __property TFormBorderStyle BorderStyle = {read=FBorderStyle, write=FBorderStyle, stored=true, default=2};
    __property TControlScrollBars* HorzScrollBar = {read=FHorzScrollBar, write=FHorzScrollBar};
    __property TPosition Position = {read=FPosition, write=FPosition, stored=true, default=0};
    __property TPrintScale PrintScale = {read=FPrintScale, write=FPrintScale, stored=true, default=1};
    __property TControlScrollBars* VertScrollBar = {read=FVertScrollBar, write=FVertScrollBar};
    __property String HelpFile = {read=FHelpFile, write=FHelpFile};
    __property Integer HelpContext = {read=FHelpContext, write=FHelpContext};
    __property Boolean ShowFieldHints = {read=FShowFieldHints, write=FShowFieldHints};
    __property TFieldOrder FieldOrder = {read=FFieldOrder, write=FFieldOrder};
    __property Boolean AutoSize = {read=FAutoSize, write=FAutoSize};
    __property Boolean HighlightPrompts = {read=FHighlightPrompts, write=FHighlightPrompts};
    __property TColor HighlightColor = {read=FHighlightColor, write=FHighlightColor};
    __property TOpType OperatorType = {read=FOpType, write=FOpType};
    __property AnsiString QueryString = {read=FQueryString, write=FQueryString};
    __property TRelation Relationship = {read=FRelation, write=FRelation, default=0};
	__property TNotifyEvent OnMDIResultOK = {read=FOnMDIResultOK, write=FOnMDIResultOK};
//	__property TIconsForBorder BorderIcons = {read=FBorderIcons, write=FBorderIcons};
    __property TBorderIcons BorderIcons = {read=FBorderIcons, write=SetBorderIcons, stored=true, default=7};
};
//---------------------------------------------------------------------------
#define MAX_OP_SYM_LEN  12
#define MAX_OP_TXT_LEN  24
#endif
 